@@ -8,17 +8,66 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw(trimTags);
 @ISA = qw(WWW::Search::Scraper Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
-use WWW::Search::Scraper(qw(generic_option addURL trimTags));
-
-use LWP::UserAgent;
-use HTML::Form;
+use WWW::Search::Scraper(qw(2.12 generic_option addURL trimTags));
 
 use strict;
 
-my $defaultScraperForm_url = ['http://www.Google.com', 'q', 'btnG', undef];
+my $scraperQuery = 
+        { 
+            # This engine is driven from it's <form> page
+            'type' => 'FORM'
+            ,'formNameOrNumber' => undef
+            ,'submitButton' => 'btnG'
+            
+            # This is the basic URL on which to get the form to build the query.
+            ,'url' => 'http://www.Google.com'
+
+           # specify defaults, by native field names
+           ,'nativeQuery' => 'q'
+           ,'nativeDefaults' => { 'hl' => 'en' }
+            
+            # specify translations from canonical fields to native fields
+           ,'fieldTranslations' =>
+                   {
+                       '*' =>
+                           {    'skills'    => 'q'
+                               ,'*'         => '*'
+                           }
+                   }
+            # Miscellaneous options for the Scraper operation.
+           ,'cookies' => 0
+       };
+
+my $scraperFrame =
+       [ 'HTML', 
+          [ 
+                  [ 'NEXT', 1, '[^>]>Next<' ], # Google keeps changing their formatting, so watch out!
+                  [ 'COUNT', '[,0-9]+</b> of about <b>([,0-9]+)</b>'] ,
+                  [ 'TABLE', '#4' ],
+                  [ 'HIT*' ,
+                    [  
+                       [ 'BODY', '<p>', '</font></font>',
+                          [
+                              [ 'AN', 'url', 'title' ],
+                              [ 'REGEX', '<font size=-1>(.*?)<br>', 'sampleText'],
+                              [ 'REGEX', '<font size=-1>Description:(.*?)<br>', 'description'],
+                              [ 'BODY',  '<span class=f>.*?Category:', '<br>',
+                                [
+                                  [ 'AN', 'categoryURL',  'category' ]
+                                ]
+                              ],
+                              [ 'AN', 'cachedURL',  undef ],
+                              [ 'AN', 'similarPagesURL', undef ]
+                          ]
+                       ]
+                    ]
+                  ]
+           ]
+       ];
+
 
 sub import
 {
@@ -30,7 +79,7 @@ sub import
     foreach (@options)
     {
         if ( $_->{'scraperBaseURL'} ) {
-            $$defaultScraperForm_url[0] = $_->{'scraperBaseURL'};
+            $scraperQuery->{'url'} = $_->{'scraperBaseURL'};
         }
     }
 
@@ -38,68 +87,9 @@ sub import
     goto &Exporter::import;
 }
 
-
-sub native_setup_search
-{
-    my($self, $native_query, $native_options_ref) = @_;
-    $self->{'_options'}{'scraperQuery'} =
-    [ 'FORM'       # 
-      # This is the basic URL on which to get the form to build the query.
-     ,$defaultScraperForm_url
-      # This names the native input field to recieve the query string.
-        ,{  
-            'nativeQuery' => 'q' # This is for non-Request type queries (ala Search.pm)
-           ,'nativeDefaults' => { }
-           ,'fieldTranslations' =>
-                   {
-                       '*' =>
-                           {    'skills'    => 'q'
-   #                            ,'payrate'   => undef
-   #                            ,'locations' => new WWW::Search::Scraper::FieldTranslation('NorthernLight', 'Job', 'locations')
-                               ,'native_query' => 'q'
-                               ,'*'         => '*'
-                           }
-                   }
-         }
-         # Some more options for the Scraper operation.
-        ,{'cookies' => 0
-         }
-       ];
-    $self->{'_http_method'} = 'GET';
-
-    $self->{'_options'}{'scrapeFrame'} = 
-       [ 'HTML', 
-          [ 
-                  [ 'NEXT', 1, '[^>]>Next<' ], # Google keeps changing their formatting, so watch out!
-                  [ 'COUNT', '[,0-9]+</b> of about <b>([,0-9]+)</b>'] ,
-                  [ 'TABLE', '#4' ],
-                  [ 'HIT*' ,
-                    [  
-                       [ 'BODY', '<p>', '</font></font>',
-                          [
-                              [ 'AN', 'url', 'title' ],
-                              [ 'REGEX', '<font size=-1>(.*?)<br>', 'description'],
-                              [ 'AN', 'cachedURL', 'cached' ],
-                              [ 'AN', 'relatedURL', 'related' ]
-                          ]
-                       ]
-                    ]
-                  ]
-           ]
-       ];
-
-    # WWW::Search::Scraper understands all that and will setup the search.
-    return $self->SUPER::native_setup_search(@_);
-
-} # native_setup_search
-
-
-{ package WWW::Search::Scraper::Response;
-
-sub moreResults {
-    return $_[0]->_elem('moreResults', $_[1]);
-}
-}
+# Access methods for the structural declarations of this Scraper engine.
+sub scraperQuery { $scraperQuery }
+sub scraperFrame { $_[0]->SUPER::scraperFrame($scraperFrame); }
 
 1;
 
